@@ -11,7 +11,7 @@ Helper for using the `Joy FeatherWing <https://www.adafruit.com/product/3632>`_.
 * Author(s): Kattni Rembor
 """
 
-__version__ = "0.0.0-auto.0"
+__version__ = "1.14.8"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FeatherWing.git"
 
 import board
@@ -173,9 +173,6 @@ class JoyFeatherWing:
     def joystick_offset(self):
         """Offset used to correctly report (0, 0) when the joystick is centered.
 
-        .. image :: ../docs/_static/joy_featherwing/joy_featherwing_joystick.jpg
-          :alt: Joy FeatherWing Joystick
-
         Provide a tuple of (x, y) to set your joystick center to (0, 0).
         The offset you provide is subtracted from the current reading.
         For example, if your joystick reads as (-4, 0), you would enter
@@ -215,9 +212,6 @@ class JoyFeatherWing:
         Note: You must not be touching the joystick at the time of zeroing
         for it to be accurate.
 
-        .. image :: ../docs/_static/joy_featherwing/joy_featherwing_joystick.jpg
-          :alt: Joy FeatherWing Joystick
-
         This example zeros the joystick, and prints the coordinates of
         joystick when it is moved.
 
