@@ -6,12 +6,12 @@
 `adafruit_featherwing.led_segments`
 ====================================================
 
-Base Class for the AlphaNumeric FeatherWing and 7-Segment FeatherWing helpers_.
+Base Class for the AlphaNumeric FeatherWing and 7-Segment FeatherWing helpers.
 
 * Author(s): Melissa LeBlanc-Williams
 """
 
-__version__ = "0.0.0-auto.0"
+__version__ = "1.14.8"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_FeatherWing.git"
 
 # pylint: disable-msg=unsubscriptable-object, unsupported-assignment-operation
@@ -23,10 +23,7 @@ except ImportError:
 
 
 class Segments:
-    """Class representing an `Adafruit 14-segment AlphaNumeric FeatherWing
-    <https://www.adafruit.com/product/3139>`_.
-
-    Automatically uses the feather's I2C bus."""
+    """Base Class for the AlphaNumeric FeatherWing and 7-Segment FeatherWing helpers."""
 
     def __init__(self):
         self._segments = None
